@@ -42,7 +42,7 @@ sub _sqlite_parse_table {
     $sth->finish;
 
     # Cut "CREATE TABLE ( )" blabla...
-    $sql =~ /^[\w\s]+\((.*)\)$/si;
+    $sql =~ /^[\w\s']+\((.*)\)$/si;
     my $cols = $1;
 
     # strip single-line comments
@@ -147,6 +147,7 @@ sub _tables_list {
     my @tables;
     while ( my $row = $sth->fetchrow_hashref ) {
         next unless lc( $row->{type} ) eq 'table';
+        next if $row->{tbl_name} =~ /^sqlite_/;
         push @tables, $row->{tbl_name};
     }
     return @tables;
